@@ -21,24 +21,30 @@ use pixi_glob::GlobHashCache;
 use pixi_record::{PinnedPathSpec, PinnedSourceSpec, PixiRecord};
 use pixi_spec::SourceSpec;
 use rattler::package_cache::PackageCache;
-use rattler_conda_types::{GenericVirtualPackage, Platform, prefix::Prefix};
+use rattler_conda_types::{GenericVirtualPackage, Platform};
 use rattler_repodata_gateway::Gateway;
 use reqwest_middleware::ClientWithMiddleware;
 use tokio::sync::{mpsc, oneshot};
 use typed_path::Utf8TypedPath;
 
 use crate::{
-    Executor, InvalidPathError, PixiEnvironmentSpec, SolveCondaEnvironmentSpec,
-    SolvePixiEnvironmentError, SourceCheckout, SourceCheckoutError, SourceMetadataSpec,
-    build::BuildCache,
+    BuildBackendMetadata, BuildBackendMetadataError, BuildBackendMetadataSpec, Executor,
+    InvalidPathError, PixiEnvironmentSpec, SolveCondaEnvironmentSpec, SolvePixiEnvironmentError,
+    SourceBuildCacheEntry, SourceBuildCacheStatusError, SourceBuildCacheStatusSpec, SourceCheckout,
+    SourceCheckoutError, SourceMetadata, SourceMetadataError, SourceMetadataSpec,
+    backend_source_build::{BackendBuiltSource, BackendSourceBuildError, BackendSourceBuildSpec},
+    build::{BuildCache, source_metadata_cache::SourceMetadataCache},
     cache_dirs::CacheDirs,
     install_pixi::{
         InstallPixiEnvironmentError, InstallPixiEnvironmentResult, InstallPixiEnvironmentSpec,
     },
-    instantiate_tool_env::{InstantiateToolEnvironmentError, InstantiateToolEnvironmentSpec},
+    instantiate_tool_env::{
+        InstantiateToolEnvironmentError, InstantiateToolEnvironmentResult,
+        InstantiateToolEnvironmentSpec,
+    },
     limits::ResolvedLimits,
-    source_build::{BuiltSource, SourceBuildError, SourceBuildSpec},
-    source_metadata::{SourceMetadata, SourceMetadataCache, SourceMetadataError},
+    solve_conda::SolveCondaEnvironmentError,
+    source_build::{SourceBuildError, SourceBuildResult, SourceBuildSpec},
 };
 
 mod builder;
@@ -160,12 +166,15 @@ impl CommandDispatcherChannel {
 ///
 /// This enum is used to track dependencies and associate tasks with specific
 /// contexts.
-#[derive(Debug, Copy, Clone, derive_more::From)]
+#[derive(Debug, Copy, Clone, derive_more::From, derive_more::TryInto, Hash, Eq, PartialEq)]
 pub(crate) enum CommandDispatcherContext {
     SolveCondaEnvironment(SolveCondaEnvironmentId),
     SolvePixiEnvironment(SolvePixiEnvironmentId),
+    BuildBackendMetadata(BuildBackendMetadataId),
+    BackendSourceBuild(BackendSourceBuildId),
     SourceMetadata(SourceMetadataId),
     SourceBuild(SourceBuildId),
+    QuerySourceBuildCache(SourceBuildCacheStatusId),
     InstallPixiEnvironment(InstallPixiEnvironmentId),
     InstantiateToolEnv(InstantiatedToolEnvId),
 }
@@ -174,8 +183,8 @@ slotmap::new_key_type! {
     /// An id that uniquely identifies a conda environment that is being solved.
     pub(crate) struct SolveCondaEnvironmentId;
 
-    /// An id that uniquely identifies a conda environment that is being solved.
-    pub(crate) struct SourceBuildId;
+    /// An id that uniquely identifies a build backend source build request.
+    pub(crate) struct BackendSourceBuildId;
 
     /// An id that uniquely identifies a conda environment that is being solved.
     pub(crate) struct SolvePixiEnvironmentId;
@@ -187,10 +196,22 @@ slotmap::new_key_type! {
     pub(crate) struct GitCheckoutId;
 }
 
+/// An id that uniquely identifies a build backend metadata request.
+#[derive(Debug, Copy, Clone, Eq, PartialEq, Hash)]
+pub(crate) struct BuildBackendMetadataId(pub usize);
+
 /// An id that uniquely identifies a source metadata request.
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Hash)]
 pub(crate) struct SourceMetadataId(pub usize);
 
+/// An id that uniquely identifies a source build request.
+#[derive(Debug, Copy, Clone, Eq, PartialEq, Hash)]
+pub(crate) struct SourceBuildId(pub usize);
+
+/// An id that uniquely identifies a source build cache request.
+#[derive(Debug, Copy, Clone, Eq, PartialEq, Hash)]
+pub(crate) struct SourceBuildCacheStatusId(pub usize);
+
 /// An id that uniquely identifies a tool environment.
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Hash)]
 pub(crate) struct InstantiatedToolEnvId(pub usize);
@@ -200,8 +221,11 @@ pub(crate) struct InstantiatedToolEnvId(pub usize);
 pub(crate) enum ForegroundMessage {
     SolveCondaEnvironment(SolveCondaEnvironmentTask),
     SolvePixiEnvironment(SolvePixiEnvironmentTask),
+    BuildBackendMetadata(BuildBackendMetadataTask),
+    BackendSourceBuild(BackendSourceBuildTask),
     SourceMetadata(SourceMetadataTask),
     SourceBuild(SourceBuildTask),
+    QuerySourceBuildCache(SourceBuildCacheStatusTask),
     GitCheckout(GitCheckoutTask),
     InstallPixiEnvironment(InstallPixiEnvironmentTask),
     InstantiateToolEnvironment(Task<InstantiateToolEnvironmentSpec>),
@@ -229,13 +253,19 @@ impl TaskSpec for InstallPixiEnvironmentSpec {
 pub(crate) type SolveCondaEnvironmentTask = Task<SolveCondaEnvironmentSpec>;
 impl TaskSpec for SolveCondaEnvironmentSpec {
     type Output = Vec<PixiRecord>;
-    type Error = rattler_solve::SolveError;
+    type Error = SolveCondaEnvironmentError;
 }
 
 /// A message that is send to the background task to requesting the metadata for
 /// a particular source spec.
-pub(crate) type SourceMetadataTask = Task<SourceMetadataSpec>;
+pub(crate) type BuildBackendMetadataTask = Task<BuildBackendMetadataSpec>;
 
+impl TaskSpec for BuildBackendMetadataSpec {
+    type Output = Arc<BuildBackendMetadata>;
+    type Error = BuildBackendMetadataError;
+}
+
+pub(crate) type SourceMetadataTask = Task<SourceMetadataSpec>;
 impl TaskSpec for SourceMetadataSpec {
     type Output = Arc<SourceMetadata>;
     type Error = SourceMetadataError;
@@ -244,16 +274,30 @@ impl TaskSpec for SourceMetadataSpec {
 pub(crate) type SourceBuildTask = Task<SourceBuildSpec>;
 
 impl TaskSpec for SourceBuildSpec {
-    type Output = BuiltSource;
+    type Output = SourceBuildResult;
     type Error = SourceBuildError;
 }
 
+pub(crate) type BackendSourceBuildTask = Task<BackendSourceBuildSpec>;
+
+impl TaskSpec for BackendSourceBuildSpec {
+    type Output = BackendBuiltSource;
+    type Error = BackendSourceBuildError;
+}
+
 /// Instantiates a tool environment.
 impl TaskSpec for InstantiateToolEnvironmentSpec {
-    type Output = Prefix;
+    type Output = InstantiateToolEnvironmentResult;
     type Error = InstantiateToolEnvironmentError;
 }
 
+pub(crate) type SourceBuildCacheStatusTask = Task<SourceBuildCacheStatusSpec>;
+
+impl TaskSpec for SourceBuildCacheStatusSpec {
+    type Output = Arc<SourceBuildCacheEntry>;
+    type Error = SourceBuildCacheStatusError;
+}
+
 impl Default for CommandDispatcher {
     fn default() -> Self {
         Self::new()
@@ -376,6 +420,14 @@ impl CommandDispatcher {
     }
 
     /// Returns the metadata of the source spec.
+    pub async fn build_backend_metadata(
+        &self,
+        spec: BuildBackendMetadataSpec,
+    ) -> Result<Arc<BuildBackendMetadata>, CommandDispatcherError<BuildBackendMetadataError>> {
+        self.execute_task(spec).await
+    }
+
+    /// Returns the metadata of a particular source package.
     pub async fn source_metadata(
         &self,
         spec: SourceMetadataSpec,
@@ -383,11 +435,28 @@ impl CommandDispatcher {
         self.execute_task(spec).await
     }
 
+    /// Query the source build cache for a particular source package.
+    pub async fn source_build_cache_status(
+        &self,
+        spec: SourceBuildCacheStatusSpec,
+    ) -> Result<Arc<SourceBuildCacheEntry>, CommandDispatcherError<SourceBuildCacheStatusError>>
+    {
+        self.execute_task(spec).await
+    }
+
     /// Builds the source package and returns the built conda package.
     pub async fn source_build(
         &self,
         spec: SourceBuildSpec,
-    ) -> Result<BuiltSource, CommandDispatcherError<SourceBuildError>> {
+    ) -> Result<SourceBuildResult, CommandDispatcherError<SourceBuildError>> {
+        self.execute_task(spec).await
+    }
+
+    /// Calls into a pixi build backend to perform a source build.
+    pub(crate) async fn backend_source_build(
+        &self,
+        spec: BackendSourceBuildSpec,
+    ) -> Result<BackendBuiltSource, CommandDispatcherError<BackendSourceBuildError>> {
         self.execute_task(spec).await
     }
 
@@ -437,7 +506,7 @@ impl CommandDispatcher {
     pub async fn solve_conda_environment(
         &self,
         spec: SolveCondaEnvironmentSpec,
-    ) -> Result<Vec<PixiRecord>, CommandDispatcherError<rattler_solve::SolveError>> {
+    ) -> Result<Vec<PixiRecord>, CommandDispatcherError<SolveCondaEnvironmentError>> {
         self.execute_task(spec).await
     }
 
@@ -451,7 +520,10 @@ impl CommandDispatcher {
     pub async fn instantiate_tool_environment(
         &self,
         spec: InstantiateToolEnvironmentSpec,
-    ) -> Result<Prefix, CommandDispatcherError<InstantiateToolEnvironmentError>> {
+    ) -> Result<
+        InstantiateToolEnvironmentResult,
+        CommandDispatcherError<InstantiateToolEnvironmentError>,
+    > {
         self.execute_task(spec).await
     }
 
@@ -474,7 +546,9 @@ impl CommandDispatcher {
         source_spec: SourceSpec,
     ) -> Result<SourceCheckout, CommandDispatcherError<SourceCheckoutError>> {
         match source_spec {
-            SourceSpec::Url(_) => unimplemented!("fetching URL sources is not yet implemented"),
+            SourceSpec::Url(url) => {
+                unimplemented!("fetching URL sources ({}) is not yet implemented", url.url)
+            }
             SourceSpec::Path(path) => {
                 let source_path = self
                     .data
