@@ -13,7 +13,7 @@ use pixi_manifest::FeaturesExt;
 use pixi_progress::await_in_progress;
 use pixi_pypi_spec::PixiPypiSpec;
 use pixi_spec::{GitSpec, PixiSpec};
-pub use pypi_prefix::update_prefix_pypi;
+pub use pypi_prefix::{ContinuePyPIPrefixUpdate, on_python_interpreter_change};
 pub use python_status::PythonStatus;
 use rattler_conda_types::Platform;
 use rattler_lock::LockedPackageRef;
