@@ -18,7 +18,7 @@ use pixi_manifest::{
 };
 use pixi_pypi_spec::{PixiPypiSpec, PypiPackageName};
 use pixi_spec::PixiSpec;
-use rattler_conda_types::{NamelessMatchSpec, PackageName, Platform, Version};
+use rattler_conda_types::{MatchSpec, NamelessMatchSpec, PackageName, Platform, Version};
 use rattler_lock::LockFile;
 use toml_edit::DocumentMut;
 
@@ -442,6 +442,48 @@ impl WorkspaceMut {
         }))
     }
 
+    // Take some conda and PyPI deps as Vecs of MatchSpecs and Requirements, and add them
+    // for given platforms and a given feature
+    pub fn add_specs(
+        &mut self,
+        conda_deps: Vec<MatchSpec>,
+        pypi_deps: Vec<Requirement>,
+        platforms: &[Platform],
+        feature_name: &FeatureName,
+    ) -> Result<(), miette::Error> {
+        for spec in conda_deps {
+            // Determine the name of the package to add
+            let (Some(name), spec) = spec.clone().into_nameless() else {
+                miette::bail!(
+                    "{} does not support wildcard dependencies",
+                    pixi_utils::executable_name()
+                );
+            };
+            let spec = PixiSpec::from_nameless_matchspec(spec, &self.workspace().channel_config());
+            self.manifest().add_dependency(
+                &name,
+                &spec,
+                SpecType::Run,
+                // No platforms required as you can't define them in the yaml
+                platforms,
+                feature_name,
+                DependencyOverwriteBehavior::Overwrite,
+            )?;
+        }
+        for requirement in pypi_deps {
+            self.manifest().add_pep508_dependency(
+                (&requirement, None),
+                // No platforms required as you can't define them in the yaml
+                platforms,
+                feature_name,
+                None,
+                DependencyOverwriteBehavior::Overwrite,
+                None,
+            )?;
+        }
+        Ok(())
+    }
+
     /// Update the conda specs of newly added packages based on the contents of
     /// the updated lock-file.
     fn update_conda_specs_from_lock_file(
